pystages.tic
============

.. automodule:: pystages.tic

.. autoclass:: Tic
    :special-members: __init__
    :members:

.. autoclass:: TicDirection
    :members:
    :undoc-members:

.. autoclass:: TicVariable 
    :members:
    :undoc-members:

